# API Reference

.. toctree::
   :maxdepth: 2
   :caption: Core

   api/base_models
   api/environments
   api/rewards
   api/schedulers
   api/types

.. toctree::
   :maxdepth: 2
   :caption: Optional

   api/images
   api/molecules
